summaryrefslogtreecommitdiff
path: root/jurt/com/sun/star/comp/loader/FactoryHelper.java
diff options
context:
space:
mode:
Diffstat (limited to 'jurt/com/sun/star/comp/loader/FactoryHelper.java')
-rw-r--r--jurt/com/sun/star/comp/loader/FactoryHelper.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/jurt/com/sun/star/comp/loader/FactoryHelper.java b/jurt/com/sun/star/comp/loader/FactoryHelper.java
index dce8818384db..d6e28435d9b5 100644
--- a/jurt/com/sun/star/comp/loader/FactoryHelper.java
+++ b/jurt/com/sun/star/comp/loader/FactoryHelper.java
@@ -136,8 +136,8 @@ public class FactoryHelper {
}
}
- if(_constructor == null) // have not found a useable constructor
- throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a useable constructor");
+ if(_constructor == null) // have not found a usable constructor
+ throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a usable constructor");
}
private final XMultiServiceFactory getSMgr( XComponentContext xContext )